@@ -1,4 +1,6 @@
-from typing import Callable, Iterable, List, Mapping, Optional, Pattern, Union
+from __future__ import annotations
+
+from typing import Callable, Iterable, Mapping, Pattern, Sequence
 
 from prompt_toolkit.completion import CompleteEvent, Completer, Completion
 from prompt_toolkit.document import Document
@@ -31,16 +33,15 @@ class WordCompleter(Completer):
 
     def __init__(
         self,
-        words: Union[List[str], Callable[[], List[str]]],
+        words: Sequence[str] | Callable[[], Sequence[str]],
         ignore_case: bool = False,
-        display_dict: Optional[Mapping[str, AnyFormattedText]] = None,
-        meta_dict: Optional[Mapping[str, AnyFormattedText]] = None,
+        display_dict: Mapping[str, AnyFormattedText] | None = None,
+        meta_dict: Mapping[str, AnyFormattedText] | None = None,
         WORD: bool = False,
         sentence: bool = False,
         match_middle: bool = False,
-        pattern: Optional[Pattern[str]] = None,
+        pattern: Pattern[str] | None = None,
     ) -> None:
-
         assert not (WORD and sentence)
 
         self.words = words
@@ -86,8 +87,8 @@ class WordCompleter(Completer):
                 display = self.display_dict.get(a, a)
                 display_meta = self.meta_dict.get(a, "")
                 yield Completion(
-                    a,
-                    -len(word_before_cursor),
+                    text=a,
+                    start_position=-len(word_before_cursor),
                     display=display,
                     display_meta=display_meta,
                 )
