@@ -22,6 +22,7 @@ stuff to do. There are two ways to detect when to return:
   asynchronous autocompletion. When the completion for instance is ready, we
   also want prompt-toolkit to gain control again in order to display that.
 """
+
 from __future__ import annotations
 
 import asyncio
@@ -66,7 +67,7 @@ InputHook: TypeAlias = Callable[[InputHookContext], None]
 
 
 def new_eventloop_with_inputhook(
-    inputhook: Callable[[InputHookContext], None]
+    inputhook: Callable[[InputHookContext], None],
 ) -> AbstractEventLoop:
     """
     Create a new event loop with the given inputhook.
@@ -77,7 +78,7 @@ def new_eventloop_with_inputhook(
 
 
 def set_eventloop_with_inputhook(
-    inputhook: Callable[[InputHookContext], None]
+    inputhook: Callable[[InputHookContext], None],
 ) -> AbstractEventLoop:
     """
     Create a new event loop with the given inputhook, and activate it.
